Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .binary_config import BinaryConfig, BinaryField

9 from .cls import TypedConfig, TypedMapping, TypedMutableMapping, update

10 from .core import (

11 check_and_convert_data,

12 convert_config,

13 ensure_types,

14 load_into,

15 load_into_class,

16 load_into_instance,

17)

18 from .dump import asbytes, asdict, asjson, astoml, asyaml

19 from .helpers import all_annotations, check_type

20 from .loaders import register_loader as loader

21 from .postpone import postpone

22 from .singleton import Singleton, SingletonMeta

23 from .type_converters import register_converter as converter

24

25 __all__ = [

26 # binary

27 "BinaryConfig",

28 "BinaryField",

29 # cls

30 "TypedConfig",

31 "TypedMapping",

32 "TypedMutableMapping",

33 "update",

34 # singleton

35 "Singleton",

36 "SingletonMeta",

37 # core

38 "check_and_convert_data",

39 "convert_config",

40 "ensure_types",

41 "load_into",

42 "load_into_class",

43 "load_into_instance",

44 # helpers

45 "all_annotations",

46 "check_type",

47 # postpone

48 "postpone",

49 # dump

50 "asbytes",

51 "asdict",

52 "astoml",

53 "asyaml",

54 "asjson",

55 # register

56 "loader",

57 "converter",

58]